\ProvidesFile{lbsenc.def}[2009/08/21 v0.5  Boisik encoding for math symbol font]
\DeclareFontEncoding{LBS}{}{}
\DeclareTextSymbol{\textasteriskcentered}{LBS}{123}
\DeclareTextSymbol{\textbackslash}{LBS}{110}
\DeclareTextSymbol{\textbar}{LBS}{106}
\DeclareTextSymbol{\textbardbl}{LBS}{107}
\DeclareTextSymbol{\textbraceleft}{LBS}{102}
\DeclareTextSymbol{\textbraceright}{LBS}{103}
\DeclareTextSymbol{\textbullet}{LBS}{15}
\DeclareTextSymbol{\textperiodcentered}{LBS}{121}
\DeclareTextSymbol{\textbigcircle}{LBS}{13}
\DeclareTextCommand{\textcircled}{LBS}[1]{\hmode@bgroup\ooalign{\hfil\raise.07ex\hbox{\upshape#1}\hfil\crcr\char13}\egroup}
\endinput
