\ProvidesFile{lbmenc.def}[2009/08/21 v0.5  Boisik encoding for second math symbol font]
\DeclareFontEncoding{LBM}{}{}
\DeclareTextSymbol{\textsection}{LBM}{240}
\DeclareTextSymbol{\textdagger}{LBM}{241}
\DeclareTextSymbol{\textdaggerdbl}{LBM}{242}
\DeclareTextSymbol{\textparagraph}{LBM}{243}
\endinput