\ProvidesFile{lblenc.def}[2009/08/21 v0.5  Boisik encoding similar to OML]
\DeclareFontEncoding{LBL}{}{}
\DeclareFontSubstitution{LBL}{bskm}{m}{it}
\DeclareTextSymbol{\textless}{LBL}{`\<}
\DeclareTextSymbol{\textgreater}{LBL}{`\>}
\DeclareTextAccent{\t}{LBL}{130}
\endinput
